#!/bin/sh

initialized=$(uci -q get system.@system[0].ati_initialized)
board=$(cat /var/sysinfo/model)
mac_id=$(sh /www/ati/scripts/get-id.sh)
ati_id=$( printf "ATI-Straton-%d" $mac_id )

initializeOnion () {
	echo "Initialize Onion Board..."
	uci set system.@system[0].ati_gpio_reset='16'
	uci set system.@system[0].klogconloglevel=5
	sh /www/ati/scripts/onion.reset-network.sh
	sh /www/ati/scripts/onion.set-hostname.sh "$ati_id"
	uci commit
}

initializeLinkit () {
	echo "Initialize Linkit Board..."
	uci set system.@system[0].ati_gpio_reset='2'
}

initializeDefaults () {
	echo "Initialize Defaults..."
	uci set system.@system[0].ati_id=""$mac_id""
	uci set system.@system[0].ati_initialized='1'
}

backupSettings () {
	echo "Backup current settings..."
	BACKUPFOLDER=/www/ati/backup-system
	if [ -d "$BACKUPFOLDER" ]; then
    		$(rm -rf $BACKUPFOLDER)
	fi	
	mkdir $BACKUPFOLDER
	$(cp /etc/config/* $BACKUPFOLDER)
}

if [ "1" != "$initialized" ] || [ "$1" == "-f" ] || [ "$1" == "--force" ]; then
	echo "Initialize ATI Device..."

	sleep 2
	mac_id=$(sh /www/ati/scripts/get-id.sh)
	ati_id=$( printf "ATI-Straton-%d" $mac_id )

	echo "Use ID $mac_id ..."
	
	initializeDefaults

	if [ "$board" == "Onion Omega2+" ]; then
		initializeOnion 
	else
		initializeLinkit
	fi

	backupSettings
	
else
	echo "ATI Device initialized:"
	echo "Board: $board"
	echo "Hostname:" $(uci get system.@system[0].hostname)
	echo "ID:" $(uci get system.@system[0].ati_id)
fi
